summaryrefslogtreecommitdiffstats
path: root/src/java/com
diff options
context:
space:
mode:
authorSven Gothel <[email protected]>2012-02-13 12:19:56 +0100
committerSven Gothel <[email protected]>2012-02-13 12:19:56 +0100
commitca99b0ba02852c6744787112af1f0e9addd45cad (patch)
tree9e66a850f4455599034179a6405e56e0008b4568 /src/java/com
parentbd5be69aee6987754f1cbf39f61280c5c72536b3 (diff)
Platform: Add Java VersionNumber
Diffstat (limited to 'src/java/com')
-rw-r--r--src/java/com/jogamp/common/os/Platform.java13
1 files changed, 11 insertions, 2 deletions
diff --git a/src/java/com/jogamp/common/os/Platform.java b/src/java/com/jogamp/common/os/Platform.java
index bd8523a..a490462 100644
--- a/src/java/com/jogamp/common/os/Platform.java
+++ b/src/java/com/jogamp/common/os/Platform.java
@@ -74,6 +74,7 @@ public class Platform {
public static final String JAVA_VM_NAME;
public static final String JAVA_RUNTIME_NAME;
public static final String JAVA_VERSION;
+ public static final VersionNumber JAVA_VERSION_NUMBER;
public static final String NEWLINE;
public enum OSType {
@@ -161,6 +162,7 @@ public class Platform {
JAVA_VENDOR = System.getProperty("java.vendor");
JAVA_VENDOR_URL = System.getProperty("java.vendor.url");
JAVA_VERSION = System.getProperty("java.version");
+ JAVA_VERSION_NUMBER = new VersionNumber(JAVA_VERSION, ".");
NEWLINE = System.getProperty("line.separator");
JAVA_VM_NAME = System.getProperty("java.vm.name");
JAVA_RUNTIME_NAME = getJavaRuntimeNameImpl();
@@ -508,7 +510,7 @@ public class Platform {
}
/**
- * Returns the JAVA.
+ * Returns the JAVA vendor.
*/
public static String getJavaVendor() {
return JAVA_VENDOR;
@@ -536,13 +538,20 @@ public class Platform {
}
/**
* Returns the JAVA vendor.
*/
public static String getJavaVersion() {
return JAVA_VERSION;
}
/**
+ * Returns the JAVA version number.
+ */
+ public static VersionNumber getJavaVersionNumber() {
+ return JAVA_VERSION_NUMBER;
+ }
+
+ /**
* Returns the JAVA vendor.
*/
public static String getNewline() {
@@ -536,13 +538,20 @@ public class Platform {
}
/**
- * Returns the JAVA vendor.
+ * Returns the JAVA version.
*/
public static String getJavaVersion() {